==> isoregistry-8.x-1.0.tar.gz: isoregistry/modules/registry_codelists/src/Controller/CodelistImporter.php <==
<?php

/**
 * @file
 * Contains \Drupal\registry_codelists\Controller\CodelistsImporter.
 */

namespace Drupal\registry_codelists\Controller;

/**
 * Description of CodelistImporter
 *
 * @author Balschmiter
 */
use Drupal\node\Entity\Node;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;



class CodelistImporter extends FormBase {
  
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'import_codelist_form';
  }
  
  public function buildForm(array $form, FormStateInterface $form_state) {
    
    /*
     * 
     * Hier muss noch die Möglichkeit geschaffen werden für:
     * 1) Auswahl ob es eine neue Version einer bestehenden Codeliste sein soll (wie wird dann mit den Codes umgegangen?)
     * 2) Die Übersetzung einer Codeliste ist
     * 3) Erweiterung einer bestehenden Codeliste (eventuell ist das aber auch schon im XML abgebildet)
     * 
     */
    
    
    $form['codelist'] = array(
      '#type' => 'managed_file',
      '#title' => $this->t('Codelist'),
      '#description' => t('nur XML Dateien im inspire geforderten Schema sind import fähig'),
      '#upload_location' => 'public://registry/imports/codelists/',
      '#required' => TRUE,
      '#upload_validators'    => [
        'file_validate_extensions'    => array('xml'),
        'file_validate_size'          => array(25600000)
      ],
    );
    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = array(
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#button_type' => 'primary',
    );
    return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $item_ids = [];
    //XML einlesen
    $file = \Drupal\file\Entity\File::load($form_state->getValue('codelist')[0]);
    //$data = file_get_contents($file->getFileUri());
    $xml = simplexml_load_file($file->getFileUri());
    //Sprache der Importer nimmt an, dass alle Werte in einer Sprache angegeben sind
    $language = (string)$xml->language;
    
    //Code der Codeliste auslesen
    $codelist_code_array = preg_split('[\/]', (string)$xml['id']);
    $codelist_code = $codelist_code_array[sizeof($codelist_code_array)-1];
    
    //Codelisten Label
    $codelist_label = (string)$xml->label;
    //Codelisten Definition
    $codelist_definition = (string)$xml->definition;
    //alle Codes anlegen und die entsprechenden NIDs ablegen (sollte ein Code bereits vorhanden sein wird dieser ignoriert und darauf verwiesen)
    foreach ($xml->xpath("//*[local-name()='containeditems']/*[local-name()='value']") as $code) {
      
      $label = (string)$code->label;
      $definition = (string)$code->definition;
      $code_array = preg_split('[\/]', (string)$code['id']);
      $code = $code_array[sizeof($code_array)-1];
      $node = Node::create([
        // The node entity bundle in this case article.
        'type' => 'registry_codelist',
        //The base language
        'langcode' => $language,
        'created' => REQUEST_TIME,
        'changed' => REQUEST_TIME,
        // The user ID.
        'title' => $code,
        'field_def_label' => $label,
        'field_def_definition' => $definition,
      ]);
      //Saving the node
      $node->save();
      dsm($node->id());
      array_push($item_ids,$node->id());
    }
    
    //Codeliste anlegen und die Codes referenzieren
    $node = Node::create([
      // The node entity bundle in this case article.
      'type' => 'registry_codelist',
      //The base language
      'langcode' => $language,
      'created' => REQUEST_TIME,
      'changed' => REQUEST_TIME,
      // The user ID.
      'title' => $codelist_code,
      'field_def_label' => $codelist_label,
      'field_def_definition' => $codelist_definition,
      'field_def_codes' => $item_ids,
    ]);
    //Saving the node
    $node->save();
  }

}

==> isoregistry-8.x-1.1.tar.gz: isoregistry/modules/registry_codelists/src/Controller/CodelistImporter.php <==
<?php

/**
 * @file
 * Contains \Drupal\registry_codelists\Controller\CodelistsImporter.
 */

namespace Drupal\registry_codelists\Controller;

/**
 * Description of CodelistImporter
 *
 * @author Balschmiter
 */
use Drupal\node\Entity\Node;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

 /*
  * 
  * 
  * es fehlt noch jegliche Art der Validierung, dies ist jedoch wichtig für die URL-Aufrufe!!!!!!!!
  * 
  * 
  * 
  * 
  */

class CodelistImporter extends FormBase {
  
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'import_codelist_form';
  }
  
  public function buildForm(array $form, FormStateInterface $form_state) {
    
    /*
     * 
     * Hier muss noch die Möglichkeit geschaffen werden für:
     * 1) Auswahl ob es eine neue Version einer bestehenden Codeliste sein soll (wie wird dann mit den Codes umgegangen?)
     * 2) das eine Übersetzung einer Codeliste ist
     * 3) Erweiterung einer bestehenden Codeliste (eventuell ist das aber auch schon im XML abgebildet, dann muss beim parser noch ergänzt werden)
     * 
     */
    
    
    $form['codelist'] = array(
      '#type' => 'managed_file',
      '#title' => $this->t('Codelist'),
      '#description' => t('nur XML Dateien im inspire geforderten Schema sind import fähig'),
      '#upload_location' => 'public://registry/imports/codelists/',
      '#required' => TRUE,
      '#upload_validators'    => [
        'file_validate_extensions'    => array('xml'),
        'file_validate_size'          => array(25600000)
      ],
    );
    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = array(
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#button_type' => 'primary',
    );
    return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $item_ids = [];
    //XML einlesen
    $file = \Drupal\file\Entity\File::load($form_state->getValue('codelist')[0]);
    //$data = file_get_contents($file->getFileUri());
    $xml = simplexml_load_file($file->getFileUri());
    //Sprache der Importer nimmt an, dass alle Werte in einer Sprache angegeben sind
    $language = (string)$xml->language;
    
    //Code der Codeliste auslesen
    $codelist_code_array = preg_split('[\/]', (string)$xml['id']);
    $codelist_code = $codelist_code_array[sizeof($codelist_code_array)-1];
    
    //Codelisten Label
    $codelist_label = (string)$xml->label;
    //Codelisten Definition
    $codelist_definition = (string)$xml->definition;
    //alle Codes anlegen und die entsprechenden NIDs ablegen (sollte ein Code bereits vorhanden sein wird dieser ignoriert und darauf verwiesen)
    foreach ($xml->xpath("//*[local-name()='containeditems']/*[local-name()='value']") as $code) {
      
      $label = (string)$code->label;
      $definition = (string)$code->definition;
      $code_array = preg_split('[\/]', (string)$code['id']);
      $code = $code_array[sizeof($code_array)-1];
      $node = Node::create([
        // The node entity bundle in this case article.
        'type' => 'registry_codelist',
        //The base language
        'langcode' => $language,
        'created' => REQUEST_TIME,
        'changed' => REQUEST_TIME,
        // The user ID.
        'title' => $code,
        'field_def_label' => $label,
        'field_def_definition' => $definition,
      ]);
      //Saving the node
      $node->save();
      array_push($item_ids,$node->id());
    }
    
    //Codeliste anlegen und die Codes referenzieren
    $node = Node::create([
      // The node entity bundle in this case article.
      'type' => 'registry_codelist',
      //The base language
      'langcode' => $language,
      'created' => REQUEST_TIME,
      'changed' => REQUEST_TIME,
      // The user ID.
      'title' => $codelist_code,
      'field_def_label' => $codelist_label,
      'field_def_definition' => $codelist_definition,
      'field_def_codes' => $item_ids,
    ]);
    //Saving the node
    $node->save();
  }

}
